import ij.*;
import ij.plugin.filter.*;
import ij.process.*;
import ij.gui.*;
import ij.measure.*;

/**	This plugin is an extended version of  ImageJ's Measure command that, in addition
	to the measurements defined in the Set Measurements dialog box,  measures area,
	total area and average area.
*/
public class Area_Calculator implements PlugInFilter, Measurements {
	ImagePlus imp;

	public int setup(String arg, ImagePlus imp) {
		if (IJ.versionLessThan("1.18o"))
			return DONE;
		this.imp = imp;
		return DOES_ALL;
	}

	public void run(ImageProcessor ip) {
		int measurements = Analyzer.getMeasurements(); // defined in Set Measurements dialog
		measurements |= AREA; //make sure area is included
		Analyzer.setMeasurements(measurements);
		Analyzer a = new Analyzer();
		ImageStatistics stats = imp.getStatistics(measurements);
		Roi roi = imp.getRoi();
		a.saveResults(stats, roi); // store in system results table
		ResultsTable rt =Analyzer.getResultsTable(); // get the system results table
		float[] areas = rt.getColumn(ResultsTable.AREA); // get area measurments
		double sum = 0.0;
		int n = areas.length;
		for (int i=0; i<n; i++)
			sum += areas[i];
		rt.addValue("Total", sum);
		rt.addValue("Average", sum/n);
		a.displayResults(); //display the results in the worksheet
		a.updateHeadings(); // update the worksheet headings
	}

}

