import ij.*;
import ij.plugin.filter.PlugInFilter;
import ij.process.*;
import ij.gui.*;
import java.awt.*;
import java.awt.event.*;
import java.util.*;

	/**
	This plugin implements the MouseListener interface and listens
	for mouse events generated by the current image.
	*/
	public class Mouse_Listener implements PlugInFilter, MouseListener {
		ImagePlus img;
		ImageCanvas canvas;
		static Vector images = new Vector();

	public int setup(String arg, ImagePlus img) {
		this.img = img;
		IJ.register(Mouse_Listener.class);
		return DOES_ALL+NO_CHANGES;
	}

	public void run(ImageProcessor ip) {
		Integer id = new Integer(img.getID());
		if (images.contains(id)) {
			IJ.write("Already listening to this image");
			return;
		} else {
			ImageWindow win = img.getWindow();
			canvas = win.getCanvas();
			canvas.addMouseListener(this);
			images.addElement(id);
		}
	}
	
	public void mousePressed(MouseEvent e) {
		int x = e.getX();
		int y = e.getY();
		int offscreenX = canvas.offScreenX(x);
		int offscreenY = canvas.offScreenY(y);
		IJ.write("Mouse pressed: "+offscreenX+","+offscreenY+modifiers(e.getModifiers()));
		//IJ.write("Right button: "+((e.getModifiers()&Event.META_MASK)!=0));
	}

    public static String modifiers(int flags) {
        String s = " [ ";
        if (flags == 0) return "";
        if ((flags & Event.SHIFT_MASK) != 0) s += "Shift ";
        if ((flags & Event.CTRL_MASK) != 0) s += "Control ";
        if ((flags & Event.META_MASK) != 0) s += "Meta (right button) ";
        if ((flags & Event.ALT_MASK) != 0) s += "Alt ";
        s += "]";
        if (s.equals(" [ ]"))
        	s = " [no modifiers]";
        return s;
    }

	public void mouseReleased(MouseEvent e) {
		IJ.write("mouseReleased: ");
	}
	
	public void mouseExited(MouseEvent e) {
	}

	public void mouseClicked(MouseEvent e) {
	}
	
	public void mouseEntered(MouseEvent e) {}
}


